@@ -369,7 +369,12 @@ void KonqPopupMenuPrivate::populate()
     m_menuActions.setItemListProperties(m_popupItemProperties);
 
     if (sReading) {
-        m_menuActions.addOpenWithActionsTo(q, QStringLiteral("DesktopEntryName != 'kfmclient' and DesktopEntryName != 'kfmclient_dir' and DesktopEntryName != 'kfmclient_html'"));
+        const QStringList excludedEntries = {
+            QStringLiteral("kfmclient"),
+            QStringLiteral("kfmclient_dir"),
+            QStringLiteral("kfmclient_html")
+        };
+        m_menuActions.insertOpenWithActionsTo(nullptr, q, excludedEntries);
 
         QList<QAction *> previewActions = m_actionGroups.value(KonqPopupMenu::PreviewActions);
         if (!previewActions.isEmpty()) {
@@ -388,6 +393,7 @@ void KonqPopupMenuPrivate::populate()
     QList<QAction *> additionalActions;
     if (isDirectory && m_popupItemProperties.items().count() == 1) {
         QAction *openTerminalHere = new QAction(QIcon::fromTheme("utilities-terminal"), i18n("Open Terminal Here"), m_parentWidget);
+        openTerminalHere->setObjectName("open-terminal-here");
         QObject::connect(openTerminalHere, &QAction::triggered, q, [this]() {
                 const QString localPath = m_popupItemProperties.urlList().constFirst().toLocalFile();
                 // 5.84 because the header wasn't usable in 5.83
@@ -414,9 +420,8 @@ void KonqPopupMenuPrivate::populate()
         q->addSeparator();
     }
 
-    if (!isCurrentTrash && !isIntoTrash && sReading &&
-            (m_popupFlags & KonqPopupMenu::NoPlugins) == 0) {
-        m_menuActions.addPluginActionsTo(q);
+    if (!isCurrentTrash && !isIntoTrash && sReading && (m_popupFlags & KonqPopupMenu::NoPlugins) == 0) {
+        m_menuActions.addActionsTo(q, KFileItemActions::MenuActionSource::Plugins);
     }
 
     if ((m_popupFlags & KonqPopupMenu::ShowProperties) && KPropertiesDialog::canDisplay(lstItems)) {
