@@ -1,12 +1,12 @@
 /*
- * Copyright (c) Martin R. Jones 1996
- *     HTML Options
- * Copyright (c) Torben Weis 1998
- *     Port to KControl
- * Copyright (c) Daniel Molkentin 2000
- *     Redesign and cleanup
- *
- */
+    SPDX-FileCopyrightText: 1996 Martin R. Jones
+    HTML Options
+    SPDX-FileCopyrightText: 1998 Torben Weis
+    Port to KControl
+    SPDX-FileCopyrightText: 2000 Daniel Molkentin
+    Redesign and cleanup
+
+*/
 
 #ifndef JAVAOPTS_H
 #define JAVAOPTS_H
