@@ -1,26 +1,14 @@
 /*
- * main.cpp
- *
- * Copyright (c) 1999 Matthias Hoelzer-Kluepfel <hoelzer@kde.org>
- * Copyright (c) 2000 Daniel Molkentin <molkentin@kde.org>
- *
- * Requires the Qt widget libraries, available at no cost at
- * http://www.troll.no/
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    main.cpp
+
+    SPDX-FileCopyrightText: 1999 Matthias Hoelzer-Kluepfel <hoelzer@kde.org>
+    SPDX-FileCopyrightText: 2000 Daniel Molkentin <molkentin@kde.org>
+
+    Requires the Qt widget libraries, available at no cost at
+    http://www.troll.no/
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 // Own
 #include "main.h"
@@ -47,14 +35,6 @@
 #include "filteropts.h"
 #include "generalopts.h"
 
-K_PLUGIN_FACTORY(KcmKonqHtmlFactory,
-                 registerPlugin<KJSParts>("khtml_java_js");
-                 registerPlugin<KMiscHTMLOptions>("khtml_behavior");
-                 registerPlugin<KKonqGeneralOptions>("khtml_general");
-                 registerPlugin<KCMFilter>("khtml_filter");
-                 registerPlugin<KAppearanceOptions>("khtml_appearance");
-                )
-
 KJSParts::KJSParts(QWidget *parent, const QVariantList &)
     : KCModule(parent)
 {
@@ -139,6 +119,3 @@ QString KJSParts::quickHelp() const
                 "fine-grained from which hosts you want to execute Java and/or "
                 "JavaScript programs.");
 }
-
-#include "main.moc"
-
