@@ -1,20 +1,8 @@
 /*
- *  Copyright (c) 2003 Lubos Lunak <l.lunak@kde.org>
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2003 Lubos Lunak <l.lunak@kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 // Own
 #include "kcmperformance.h"
@@ -28,10 +16,8 @@
 #include "konqueror.h"
 #include "system.h"
 #include <KPluginFactory>
-K_PLUGIN_FACTORY(KCMPerformanceConfigFactory,
-                 registerPlugin<KCMPerformance::Config>("performance");
-                 registerPlugin<KCMPerformance::KonquerorConfig>("konqueror");
-                )
+
+K_PLUGIN_FACTORY_WITH_JSON(KCMPerformanceConfigFactory, "kcmperformance.json", registerPlugin<KCMPerformance::KonquerorConfig>();)
 
 namespace KCMPerformance
 {
