@@ -20,6 +20,7 @@
 #include "konqmainwindow.h"
 #include "konqmainwindowfactory.h"
 #include "konqmisc.h"
+#include <config-konqueror.h>
 
 #include <QDBusConnection>
 #include <QDBusMessage>
@@ -44,6 +45,18 @@
 #include <iostream>
 #include <unistd.h>
 
+#ifdef KActivities_FOUND
+#include <KActivities/Consumer>
+#endif
+
+#ifdef KActivities_FOUND
+QString KonquerorApplication::currentActivity()
+{
+    KonquerorApplication* app = qobject_cast<KonquerorApplication*>(QApplication::instance());
+    return app ? app->m_activityConsumer->currentActivity() : QString();
+}
+#endif
+
 KonquerorApplication::KonquerorApplication(int &argc, char **argv)
     : QApplication(argc, argv)
 {
@@ -77,6 +90,10 @@ KonquerorApplication::KonquerorApplication(int &argc, char **argv)
 
     qputenv("QTWEBENGINE_CHROMIUM_FLAGS", flags);
     KLocalizedString::setApplicationDomain("konqueror");
+
+#ifdef KActivities_FOUND
+    m_activityConsumer = new KActivities::Consumer(this);
+#endif
 }
 
 KonquerorApplication::KonquerorAsRootBehavior KonquerorApplication::checkRootBehavior()
@@ -186,7 +203,9 @@ void KonquerorApplication::setupParser()
     m_parser.addOption(QCommandLineOption(QStringList{QStringLiteral("part")}, i18n("Part to use (e.g. khtml or kwebkitpart)"), i18n("service")));
     m_parser.addOption(QCommandLineOption(QStringList{QStringLiteral("select")}, i18n("For URLs that point to files, opens the directory and selects the file, instead of opening the actual file")));
     m_parser.addOption(QCommandLineOption(QStringList{QStringLiteral("tempfile")}, i18n("The files/URLs opened by the application will be deleted after use")));
-
+#ifdef DEVELOPER_MODE
+    m_parser.addOption(QCommandLineOption({QStringLiteral("force-new-process")}, i18n("Create a new Konqueror process, even if one already exists. Meant to be used only when developing Konqueror itself")));
+#endif
     m_parser.addPositionalArgument(QStringLiteral("[URL]"), i18n("Location to open"));
 }
 
@@ -253,6 +272,11 @@ int KonquerorApplication::start()
 
     m_parser.process(*this);
     m_aboutData.processCommandLine(&m_parser);
+#ifdef DEVELOPER_MODE
+    bool forceNewProcess = m_runningAsRootBehavior != NotRoot || m_parser.isSet(QStringLiteral("force-new-process"));
+#else
+    bool forceNewProcess = m_runningAsRootBehavior != NotRoot;
+#endif
 
     //Explicitly disable reusing existing instances if running as root. The behavior is not clear
     //and could be dangerous if new windows are unknowingly launched as root.
@@ -260,7 +284,9 @@ int KonquerorApplication::start()
     //so prevents the new window to be created because the new instance produces a critical failure with message:
     //Couldn't register name 'org.kde.konqueror' with DBUS - another process owns it already!
     //Moving the service creation outside the if block seems to solve the issue.
-    KDBusService dbusService(m_runningAsRootBehavior == NotRoot ? KDBusService::Unique : KDBusService::Multiple | KDBusService::NoExitOnFailure);
+    //
+    //This also disables reusing an existing instance when running in developer mode
+    KDBusService dbusService(forceNewProcess ? KDBusService::Multiple | KDBusService::NoExitOnFailure : KDBusService::Unique);
     if (m_runningAsRootBehavior == NotRoot) {
         auto activateApp = [this](const QStringList &arguments, const QString &workingDirectory) {
             m_parser.parse(arguments);
@@ -310,23 +336,33 @@ int KonquerorApplication::performStart(const QString& workingDirectory, bool fir
     }
 
     WindowCreationResult result;
-    if (args.isEmpty()) {
-        result = createEmptyWindow(firstInstance);
+
+    bool sessionRestored = KonqSessionManager::self()->restoreSessionSavedAtExit();
+    if (!args.isEmpty()) {
+        //KonqSessionManager::restoreSessionSavedAtExit only returns true if there's at least one main window,
+        //so there's no need to check whether the list is empty
+        result = createWindowsForUrlArguments(args, workingDirectory, sessionRestored ? KonqMainWindow::mainWindows().at(0) : nullptr);
+    } else if (sessionRestored){
+        result = WindowCreationResult{KonqMainWindow::mainWindows().at(0), 0};
     } else {
-        result = createWindowsForUrlArguments(args, workingDirectory);
+        result = createEmptyWindow(firstInstance);
     }
 
     KonqMainWindow *mw = result.first;
     if (!firstInstance && mw) {
         mw ->setAttribute(Qt::WA_NativeWindow, true);
-        KStartupInfo::setNewStartupId(mw->windowHandle(), QX11Info::nextStartupId());
-        KX11Extras::forceActiveWindow(mw->winId());
+        if (KWindowSystem::isPlatformX11()) {
+            KStartupInfo::setNewStartupId(mw->windowHandle(), QX11Info::nextStartupId());
+            KX11Extras::forceActiveWindow(mw->winId());
+        } else {
+            KStartupInfo::setNewStartupId(mw->windowHandle(), qEnvironmentVariable("XDG_ACTIVATION_TOKEN").toUtf8());
+        }
     }
 
     return result.second;
 }
 
-KonquerorApplication::WindowCreationResult KonquerorApplication::createWindowsForUrlArguments(const QStringList& args, const QString &workingDirectory)
+KonquerorApplication::WindowCreationResult KonquerorApplication::createWindowsForUrlArguments(const QStringList& args, const QString &workingDirectory, KonqMainWindow *mainwin)
 {
     QList<QUrl> urlList;
     urlList.reserve(args.length());
@@ -373,15 +409,26 @@ KonquerorApplication::WindowCreationResult KonquerorApplication::createWindowsFo
     req.tempFile = m_parser.isSet("tempfile");
     req.serviceName = m_parser.value("part");
 
-    KonqMainWindow *mainwin = KonqMainWindowFactory::createNewWindow(firstUrl, req);
     if (!mainwin) {
-        return qMakePair(nullptr, 1);
+        mainwin = KonqMainWindowFactory::createNewWindow(firstUrl, req);
+        if (!mainwin) {
+            return qMakePair(nullptr, 1);
+        }
+    } else {
+        req.browserArgs.setNewTab(true);
+        mainwin->openUrl(nullptr, firstUrl, req.args.mimeType(), req);
     }
+
     mainwin->show();
     if (!urlList.isEmpty()) {
         // Open the other urls as tabs in that window
         mainwin->openMultiURL(urlList);
     }
+
+    //Ensure the last tab is activated. This happens automatically if a new main window was created
+    //but not if an existing main window was passed as argument, which is the case if the last Konqueror
+    //session was restored
+    mainwin->activateTab(mainwin->tabsCount()-1);
     return qMakePair(mainwin, 0);
 }
 
