@@ -107,11 +107,8 @@ QString KonqPixmapProvider::iconNameFor(const QUrl &url)
     }
 
     if (url.url().isEmpty()) {
-        // Use the folder icon for the empty URL
-        QMimeDatabase db;
-        const QMimeType directoryType = db.mimeTypeForName(QStringLiteral("inode/directory"));
-        icon = directoryType.iconName();
-        Q_ASSERT(!icon.isEmpty());
+        // Use the Konqueror icon for the empty URL
+        icon = "konqueror";
     } else {
         icon = KIO::iconNameForUrl(url);
         Q_ASSERT(!icon.isEmpty());
