@@ -27,6 +27,7 @@
 #include <KApplicationTrader>
 #include <KParts/PartLoader>
 #include <KLocalizedString>
+#include <KIO/JobUiDelegateFactory>
 
 #include <QDebug>
 #include <QArgument>
@@ -61,6 +62,9 @@ UrlLoader::UrlLoader(KonqMainWindow *mainWindow, KonqView *view, const QUrl &url
     QObject(mainWindow), m_mainWindow(mainWindow), m_url(url), m_mimeType(mimeType), m_request(req), m_view(view), m_trustedSource(trustedSource), m_dontEmbed(dontEmbed),
     m_jobErrorCode(0), m_protocolAllowsReading(KProtocolManager::supportsReading(m_url))
 {
+    if (!isMimeTypeKnown(m_mimeType)) {
+        m_mimeType = m_request.args.mimeType();
+    }
     m_dontPassToWebEnginePart = m_request.args.metaData().contains("DontSendToDefaultHTMLPart");
 }
 
@@ -255,14 +259,11 @@ void UrlLoader::decideOpenOrSave()
     if (!alwaysOpen) {
         answerWithService = askSaveOrOpen(OpenEmbedMode::Open);
     } else {
-        answerWithService = qMakePair(OpenUrlAction::Open, nullptr);
+        answerWithService = qMakePair(OpenUrlAction::Open, KApplicationTrader::preferredService(m_mimeType));
     }
 
     m_action = answerWithService.first;
     m_service = answerWithService.second;
-    if (m_action == OpenUrlAction::Open && !m_service) {
-        m_service= KApplicationTrader::preferredService(m_mimeType);
-    }
 }
 
 UrlLoader::OpenUrlAction UrlLoader::decideExecute() const {
@@ -355,6 +356,12 @@ void UrlLoader::mimetypeDeterminedByJob()
 {
     if (!m_mimeTypeFinderJob->error()) {
         m_mimeType=m_mimeTypeFinderJob->mimeType();
+        //Only check whether the URL represents an archive when it is a local file. This can be either because
+        //QUrl::isLocalFile returns true or because its scheme corresponds to a protocol with class :local
+        //(for example, tar)
+        if (m_url.isLocalFile() || KProtocolInfo::protocolClass(m_url.scheme()) == QLatin1String(":local")) {
+            detectArchiveSettings();
+        }
         decideAction();
     } else {
         m_jobErrorCode = m_mimeTypeFinderJob->error();
@@ -409,6 +416,37 @@ int UrlLoader::checkAccessToLocalFile(const QString& path)
     }
 }
 
+void UrlLoader::detectArchiveSettings()
+{
+    // Generic mechanism for redirecting to tar:/<path>/ when clicking on a tar file,
+    // zip:/<path>/ when clicking on a zip file, etc.
+    // The .protocol file specifies the mimetype that the kioslave handles.
+    // Note that we don't use mimetype inheritance since we don't want to
+    // open OpenDocument files as zip folders...
+    const QString protocol = KProtocolManager::protocolForArchiveMimetype(m_mimeType);
+    if (protocol.isEmpty() && !KProtocolInfo::archiveMimetypes(m_url.scheme()).isEmpty() && m_mimeType == QLatin1String("inode/directory")) {
+        m_url.setScheme(QStringLiteral("file"));
+    } else if (!protocol.isEmpty() && KonqFMSettings::settings()->shouldEmbed(m_mimeType)) {
+        m_url.setScheme(protocol);
+        //If the URL ends with /, we assume that it was the result of the user using the Up button while displaying the webarchive.
+        //This means that we don't want to add the /index.html part, otherwise the effect will be to have the same URL but with
+        //an increasing number of slashes before index.html
+        if (m_mimeType == QLatin1String("application/x-webarchive") && !m_url.path().endsWith('/')) {
+            m_url.setPath(m_url.path() + QStringLiteral("/index.html"));
+            m_mimeType = QStringLiteral("text/html");
+        } else {
+            if (KProtocolManager::outputType(m_url) == KProtocolInfo::T_FILESYSTEM) {
+                if (!m_url.path().endsWith('/')) {
+                    m_url.setPath(m_url.path() + '/');
+                }
+                m_mimeType = QStringLiteral("inode/directory");
+            } else {
+                m_mimeType.clear();
+            }
+        }
+    }
+}
+
 void UrlLoader::detectSettingsForLocalFiles()
 {
     if (!m_url.isLocalFile()) {
@@ -418,31 +456,7 @@ void UrlLoader::detectSettingsForLocalFiles()
     m_jobErrorCode = checkAccessToLocalFile(m_url.path());
 
     if (!m_mimeType.isEmpty()) {
-        // Generic mechanism for redirecting to tar:/<path>/ when clicking on a tar file,
-        // zip:/<path>/ when clicking on a zip file, etc.
-        // The .protocol file specifies the mimetype that the kioslave handles.
-        // Note that we don't use mimetype inheritance since we don't want to
-        // open OpenDocument files as zip folders...
-        // Also note that we do this here and not in openView anymore,
-        // because in the case of foo.bz2 we don't know the final mimetype, we need a konqrun...
-        const QString protocol = KProtocolManager::protocolForArchiveMimetype(m_mimeType);
-        if (!protocol.isEmpty() && KonqFMSettings::settings()->shouldEmbed(m_mimeType)) {
-            m_url.setScheme(protocol);
-            if (m_mimeType == QLatin1String("application/x-webarchive")) {
-                m_url.setPath(m_url.path() + QStringLiteral("/index.html"));
-                m_mimeType = QStringLiteral("text/html");
-            } else {
-                if (KProtocolManager::outputType(m_url) == KProtocolInfo::T_FILESYSTEM) {
-                    if (!m_url.path().endsWith('/')) {
-                        m_url.setPath(m_url.path() + '/');
-                    }
-                    m_mimeType = QStringLiteral("inode/directory");
-                } else {
-                    m_mimeType.clear();
-                }
-            }
-        }
-
+        detectArchiveSettings();
         // Redirect to the url in Type=Link desktop files
         if (m_mimeType == QLatin1String("application/x-desktop")) {
             KDesktopFile df(m_url.toLocalFile());
@@ -523,19 +537,13 @@ void UrlLoader::open()
     }
 
     KJob *job = nullptr;
-    if (m_service) {
-        KIO::ApplicationLauncherJob *j = new KIO::ApplicationLauncherJob(m_service);
-        j->setUrls({m_url});
-        j->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, m_mainWindow));
-        if (m_request.tempFile) {
-            j->setRunFlags(KIO::ApplicationLauncherJob::DeleteTemporaryFiles);
-        }
-        job = j;
-    } else {
-        KIO::OpenUrlJob *j = new KIO::OpenUrlJob(m_url);
-        j->setDeleteTemporaryFile(m_request.tempFile);
-        job = j;
+    KIO::ApplicationLauncherJob *j = new KIO::ApplicationLauncherJob(m_service);
+    j->setUrls({m_url});
+    j->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, m_mainWindow));
+    if (m_request.tempFile) {
+        j->setRunFlags(KIO::ApplicationLauncherJob::DeleteTemporaryFiles);
     }
+    job = j;
     connect(job, &KJob::finished, this, [this, job](){done(job);});
     job->start();
 }
@@ -545,7 +553,7 @@ void UrlLoader::execute()
     m_openUrlJob = new KIO::OpenUrlJob(m_url, m_mimeType, this);
     m_openUrlJob->setEnableExternalBrowser(false);
     m_openUrlJob->setRunExecutables(true);
-    m_openUrlJob->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, m_mainWindow));
+    m_openUrlJob->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, m_mainWindow));
     m_openUrlJob->setSuggestedFileName(m_request.suggestedFileName);
     m_openUrlJob->setDeleteTemporaryFile(m_request.tempFile);
     connect(m_openUrlJob, &KJob::finished, this, [this]{done(m_openUrlJob);});
