@@ -107,8 +107,6 @@ public:
 
     WebEngineWallet* wallet() const;
 
-    static QWebEngineScript detectRefreshScript();
-
     /**
      * @brief Changes the page object associated with the part
      *
@@ -121,6 +119,9 @@ public:
      */
     void setPage(WebEnginePage *newPage);
 
+    WebEnginePage* page();
+    const WebEnginePage* page() const;
+
     QWebEngineProfile *profile() const;
 
     bool isWebEnginePart() const {return true;}
@@ -180,10 +181,9 @@ private Q_SLOTS:
     void updateWalletStatusBarIcon();
     void walletFinishedFormDetection(const QUrl &url, bool found, bool autoFillableFound);
     void updateWalletActions();
+    void reloadAfterUAChange(const QString &);
 
 private:
-    WebEnginePage* page();
-    const WebEnginePage* page() const;
     static void initWebEngineUrlSchemes();
 
     void deleteStatusBarWalletLabel();
