@@ -20,6 +20,7 @@
 #include "webenginepart.h"
 #include "webenginepage.h"
 #include "navigationrecorder.h"
+#include <webenginepart_debug.h>
 
 #include <KProtocolInfo>
 #include <KSharedConfig>
@@ -32,6 +33,7 @@
 #include <QApplication>
 #include <QLocale>
 #include <QSettings>
+#include <QJsonDocument>
 
 WebEnginePartControls::WebEnginePartControls(): QObject(),
     m_profile(nullptr), m_cookieJar(nullptr), m_spellCheckerManager(nullptr), m_downloadManager(nullptr),
@@ -70,14 +72,72 @@ bool WebEnginePartControls::isReady() const
     return m_profile;
 }
 
+void WebEnginePartControls::registerScripts()
+{
+    if (!m_profile) {
+        qCDebug(WEBENGINEPART_LOG) << "Attempting to register scripts before setting the profile";
+        return;
+    }
+
+    QFile jsonFile(QStringLiteral(":/scripts.json"));
+    jsonFile.open(QIODevice::ReadOnly);
+    QJsonObject obj = QJsonDocument::fromJson(jsonFile.readAll()).object();
+    Q_ASSERT(!obj.isEmpty());
+    jsonFile.close();
+    for (auto it = obj.constBegin(); it != obj.constEnd(); ++it) {
+        QJsonObject scriptData = it.value().toObject();
+        Q_ASSERT(!scriptData.isEmpty());
+        QWebEngineScript script = scriptFromJson(it.key(), scriptData);
+        if (!script.isNull()) {
+            m_profile->scripts()->insert(script);
+        }
+    }
+}
+
+QWebEngineScript WebEnginePartControls::scriptFromJson(const QString& name, const QJsonObject& obj)
+{
+    QWebEngineScript script;
+    QString file = obj.value(QLatin1String("file")).toString();
+    if (file.isEmpty()) {
+        return script;
+    }
+    QFile sourceFile(file);
+    sourceFile.open(QIODevice::ReadOnly);
+    Q_ASSERT(sourceFile.isOpen());
+    script.setSourceCode(QString(sourceFile.readAll()));
+    QJsonValue val = obj.value(QLatin1String("injectionPoint"));
+    if (!val.isNull()) {
+        int injectionPoint = val.toInt(-1);
+        //NOTE:keep in sync with the values of QWebEngineScript::InjectionPoint
+        Q_ASSERT(injectionPoint >=QWebEngineScript::Deferred && injectionPoint <= QWebEngineScript::DocumentCreation);
+        script.setInjectionPoint(static_cast<QWebEngineScript::InjectionPoint>(injectionPoint));
+    }
+    val = obj.value(QLatin1String("worldId"));
+    if (!val.isNull()) {
+        int world= val.toInt(-1);
+        //NOTE: keep in sync with the values of QWebEngineScript::ScriptWorldId
+        Q_ASSERT(world >= QWebEngineScript::MainWorld);
+        script.setWorldId(world);
+    }
+    val = obj.value(QStringLiteral("runsOnSubFrames"));
+    if (!val.isBool()) {
+        script.setRunsOnSubFrames(val.toBool());
+    }
+    script.setName(name);
+    return script;
+}
+
 void WebEnginePartControls::setup(QWebEngineProfile* profile)
 {
     if (!profile || isReady()) {
         return;
     }
     m_profile = profile;
+    m_defaultUserAgent = m_profile->httpUserAgent() + QLatin1String(" Konqueror (WebEngine)");
+    //This property is used to communicate the default user agent to the UserAgent settings widget
+    m_profile->setProperty("defaultUserAgent",m_defaultUserAgent);
 
-    m_profile->scripts()->insert({WebEngineWallet::formDetectorFunctionsScript(), WebEnginePart::detectRefreshScript()});
+    registerScripts();
 
     m_profile->installUrlSchemeHandler("error", new WebEnginePartErrorSchemeHandler(m_profile));
     m_profile->installUrlSchemeHandler("konq", new KonqUrlSchemeHandler(m_profile));
@@ -153,16 +213,40 @@ void WebEnginePartControls::reparseConfiguration()
         return;
     }
     KSharedConfig::Ptr cfg = KSharedConfig::openConfig();
-    KConfigGroup grp = cfg->group("Cache");
-    if (grp.readEntry("CacheEnabled", true)) {
-        QWebEngineProfile::HttpCacheType type = grp.readEntry("MemoryCache", false) ? QWebEngineProfile::MemoryHttpCache : QWebEngineProfile::DiskHttpCache;
+    KConfigGroup grp = cfg->group(QStringLiteral("Cache"));
+    if (grp.readEntry(QStringLiteral("CacheEnabled"), true)) {
+        QWebEngineProfile::HttpCacheType type = grp.readEntry(QStringLiteral("MemoryCache"), false) ? QWebEngineProfile::MemoryHttpCache : QWebEngineProfile::DiskHttpCache;
         m_profile->setHttpCacheType(type);
-        m_profile->setHttpCacheMaximumSize(grp.readEntry("MaximumCacheSize", 0));
+        m_profile->setHttpCacheMaximumSize(grp.readEntry(QStringLiteral("MaximumCacheSize"), 0));
         //NOTE: According to the documentation, setCachePath resets the cache path to its default value if the argument is a null QString
         //it doesn't specify what it does if the string is empty but not null. Experimenting, it seems the behavior is the same
-        m_profile->setCachePath(grp.readEntry("CustomCacheDir", QString()));
+        m_profile->setCachePath(grp.readEntry(QStringLiteral("CustomCacheDir"), QString()));
 
     } else {
         m_profile->setHttpCacheType(QWebEngineProfile::NoCache);
     }
+
+    grp = KSharedConfig::openConfig(QString(), KConfig::NoGlobals)->group(QStringLiteral("UserAgent"));
+    bool useCustomUserAgent = grp.readEntry(QStringLiteral("UseCustomUserAgent"), false);
+    QString userAgent = useCustomUserAgent ? grp.readEntry(QStringLiteral("CustomUserAgent"), m_defaultUserAgent) : m_defaultUserAgent;
+    setHttpUserAgent(userAgent);
+}
+
+QString WebEnginePartControls::httpUserAgent() const
+{
+    return m_profile ? m_profile->httpUserAgent() : QString();
+}
+
+void WebEnginePartControls::setHttpUserAgent(const QString& uaString)
+{
+    if (!m_profile || m_profile->httpUserAgent() == uaString) {
+        return;
+    }
+    m_profile->setHttpUserAgent(uaString);
+    emit userAgentChanged(uaString);
+}
+
+QString WebEnginePartControls::defaultHttpUserAgent() const
+{
+    return m_defaultUserAgent;
 }
