@@ -72,7 +72,7 @@ WebEngineView::~WebEngineView()
     //qCDebug(WEBENGINEPART_LOG);
 }
 
-void WebEngineView::loadUrl(const QUrl& url, const KParts::OpenUrlArguments& args, const KParts::BrowserArguments& bargs, bool force)
+void WebEngineView::loadUrl(const QUrl& url, const KParts::OpenUrlArguments& args, const KParts::BrowserArguments& bargs)
 {
     WebEnginePage *pg = qobject_cast<WebEnginePage*>(page());
     if (!pg) {
@@ -614,16 +614,17 @@ void WebEngineView::addSearchActions(QList<QAction*>& selectActions, QWebEngineV
     }
 }
 
-void WebEngineView::acceptDragMoveEventIfPossible(QDragMoveEvent* e)
+#ifndef REMOTE_DND_NOT_HANDLED_BY_WEBENGINE
+void WebEngineView::dropEvent(QDropEvent* e)
 {
-    if (!e->isAccepted() && e->mimeData()->hasUrls()) {
-        e->acceptProposedAction();
-        m_dragAndDropHandledBySuperclass = false;
-    } else {
-        m_dragAndDropHandledBySuperclass = true;
+    WebEnginePage *pg = qobject_cast<WebEnginePage*>(page());
+    if (pg) {
+        pg->setDropOperationStarted();
     }
+    QWebEngineView::dropEvent(e);
 }
 
+#else
 void WebEngineView::dropEvent(QDropEvent* e)
 {
     QWebEngineView::dropEvent(e);
@@ -637,6 +638,16 @@ void WebEngineView::dropEvent(QDropEvent* e)
     }
 }
 
+void WebEngineView::acceptDragMoveEventIfPossible(QDragMoveEvent* e)
+{
+    if (!e->isAccepted() && e->mimeData()->hasUrls()) {
+        e->acceptProposedAction();
+        m_dragAndDropHandledBySuperclass = false;
+    } else {
+        m_dragAndDropHandledBySuperclass = true;
+    }
+}
+
 void WebEngineView::dragEnterEvent(QDragEnterEvent* e)
 {
     QWebEngineView::dragEnterEvent(e);
@@ -648,3 +659,4 @@ void WebEngineView::dragMoveEvent(QDragMoveEvent* e)
     QWebEngineView::dragMoveEvent(e);
     acceptDragMoveEventIfPossible(e);
 }
+#endif
